@@ -1,3 +1,6 @@
+#' @import utils
+NULL
+
 #' Tables for mapping filename extensions to MIME types
 #'
 #' The data \code{mimemap} is a named character vector that stores the filename
@@ -18,11 +21,10 @@ local({
 
   # the code is executed only when called from Rd2roxygen
   if (!('Rd2roxygen' %in% loadedNamespaces())) return()
-  # run the code here only during roxygenize(), when the working dir is mime/R/
-  if (basename(getwd()) != 'R') return()
+  if (file.access('R/mimemap.R', 2) != 0) return()
   # do nothing if we are not under *nix; could read Windows registry, but who cares...
   if (!file.exists(mimefile <- '/etc/mime.types')) return()
-  message('* Updating mimemap.R')
+  message('* Updating R/mimemap.R')
 
   lines = readLines(mimefile, warn = FALSE)
   # remove comments and blank lines
@@ -48,7 +50,7 @@ local({
       lines
     ), collapse = ',\n'),
     ')'
-  ), con = 'mimemap.R')
+  ), con = 'R/mimemap.R')
 
 })
 
@@ -56,8 +58,7 @@ local({
 #' @usage NULL
 #' @format NULL
 mimeextra = c(
-  md = "text/x-markdown",
-  markdown = "text/x-markdown",
+  geojson = "application/vnd.geo+json",
   r = "text/plain",
   rd = "text/plain",
   rmd = "text/x-markdown",
@@ -118,3 +119,10 @@ guess_type = function(file, unknown = 'application/octet-stream',
   }
   type
 }
+
+if (.Platform$OS.type == 'windows') basename = function(path) {
+  if (length(path) == 0) return(path)
+  tryCatch(base::basename(path), error = function(e) {
+    vapply(strsplit(path, '[\\/]+'), tail, character(1), 1, USE.NAMES = FALSE)
+  })
+}
